@@ -46,7 +46,7 @@ def check_rcfile():
     """See default.config for rcfileversion values, meanings and
     a description of how to add config variables.
     """
-    rcfileversion = 15
+    rcfileversion = 18
     if cfg.get_int("app/rcfileversion") > rcfileversion:
         cfg.drop_user_config()
         return
@@ -116,6 +116,13 @@ def check_rcfile():
             cfg.set_string("sound/%s_player" % k, v[0])
             cfg.set_string("sound/%s_player_options" % k,
                 " ".join(v[1:]))
+    if cfg.get_int("app/rcfileversion") < 17:
+        v = cfg.get_string("app/frontpage").split("/")
+        if v[0] == u"exercises":
+            cfg.set_string("app/frontpage", 
+                           u"/".join([v[0], u"standard"] + v[1:]))
+    if cfg.get_int("app/rcfileversion") < 18:
+        cfg.del_key("gui/web_browser_as_help_browser")
     cfg.set_int("app/rcfileversion", rcfileversion)
     try:
         a = mpd.notename_to_int(cfg.get_string("user/lowest_pitch"))
@@ -305,75 +312,14 @@ class SolfegeApp(cfg.ConfigUtils):
         solfege.win.box_dict[module].on_start_practise()
         solfege.win.enter_test_mode()
     def handle_href(self, href, display_docfile_set_adj=1):
-        # All generatet docbook documents are in utf-8
         urlobj = utils.Url(href)
         if not urlobj.protocol:
-            if urlobj.filename.endswith(".midi"):
-                if os.path.exists(os.path.join(solfege.win.box_dict['docviewer'].m_htmlwidget.m_document_wd, urlobj.filename)):
-                    midifilename = urlobj.filename
-                elif len(urlobj.filename.split('-')) > 1:
-                    # Filename-nl.midi => Filename.midi
-                    v = urlobj.filename.split('-')
-                    w = v[-1].split('.')
-                    midifilename = "-".join(v[:-1])+"."+w[1]
-                else:
-                    midifilename = urlobj.filename
-
-                soundcard.play_mediafile("midi", os.path.join(
-                    solfege.win.box_dict['docviewer'].m_htmlwidget.m_document_wd,
-                    midifilename))
-            else:
-                solfege.win.display_docfile(urlobj.filename, urlobj.anchor)
-        elif urlobj.protocol == 'solfege':
-            self.handle_solfege_href(urlobj)
-        elif urlobj.protocol == 'http':
+            solfege.win.display_docfile(urlobj.filename, urlobj.anchor)
+        else:
             try:
                 webbrowser.open_new(href)
             except Exception, e:
                 solfege.win.display_error_message2(_("Error opening web browser"), str(e))
-        elif urlobj.protocol == 'mailto':
-            if self.get_string("config/mua"):
-                try:
-                    cmdline = self.get_string("config/mua") % urlobj.href
-                except TypeError:
-                    cmdline = "%s %s" % (self.get_string("config/mua"), urlobj.href)
-                os.system(cmdline)
-            else:
-                gu.dialog_ok(_("You have not selected email program. You can do so in the preferences window."))
-        else:
-            gu.dialog_ok("unknown link type: %s" % urlobj.protocol)
-    def handle_solfege_href(self, urlobj):
-        """
-        This method handles three kins of urls:
-        solfege:practise/lesson_id
-            practise the exercise with the lesson id 'lesson_id'
-        solfege:practise/path/to/lessonfile
-            Practise a specific lessonfile. Relative path:
-                solfege:practise/lesson-files/chord-min-major
-            Absolute path:
-                solfege:practise//home/user/src/solfege/lesson-files/filename
-        """
-        solfege.win.hide_help_on_current()
-        # the Url class does not know anything about lesson ids, but we
-        # assume that lesson_ids don't include the '/' character.
-        if '/' not in urlobj.lessonfile:
-            self.practise_lesson_id(urlobj.lessonfile)#FIXME practise_lessonfile
-            return
-        if urlobj.lessonfile:
-            if not os.path.isfile(urlobj.lessonfile):
-                solfege.win.display_error_message(_("Lessonfile not found:\n%s") % urlobj.lessonfile)
-                return
-        p = lessonfile.LessonfileCommon()
-        p.parse_file(urlobj.lessonfile)
-        self._practise_lessonfile(p.header.lesson_id, urlobj)#FIXME test
-        # This loop changes variables in the lesson file header if they
-        # have set values in the url.
-        for key, val in urlobj.config.iteritems():
-            try:
-                self.m_teachers[p.header.module].m_P.header[key] = eval(val)
-            except SyntaxError:
-                gu.dialog_ok(_("Bad url parameter in link: '%s'.\nTrying to continue anyway.") % ("%s=%s" % (key, val)))
-        solfege.win.box_dict[p.header.module].on_start_practise()
     def create_teacher(self, modulename):
         """
         Create the teacher in 'modulename' and add it to self.m_teachers.
