@@ -273,18 +273,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             cbox_entry.warning.props.no_show_all = True
             csound_changed_cb(cbox_entry, bin)
             cbox_entry.connect('changed', csound_changed_cb, bin)
-        # Mail program
-        liststore = gtk.ListStore(gobject.TYPE_STRING)
-        for n in osutils.find_progs(('mutt', 'thunderbird', 'evolution')):
-            if os.path.split(n)[1] == 'mutt':
-                n = "xterm -e %s" % n
-            liststore.append((n,))
-        self.g_mail_program = gtk.ComboBoxEntry(liststore)
-        self.g_mail_program.child.set_text(self.get_string("config/mua"))
-        self.g_mail_program.child.connect('changed', lambda w: self.set_string('config/mua', self.g_mail_program.child.get_text()))
-        box = gu.hig_label_widget(_("_Mail:"), self.g_mail_program, sizegroup,
-            True, True)
-        category_vbox.pack_start(box)
 
         #######
         # Gui #
@@ -295,9 +283,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         box, category_vbox = gu.hig_category_vbox(_("Interface"))
         page_vbox.pack_start(box, False)
 
-        b = gu.nCheckButton('gui', 'web_browser_as_help_browser',
-            _("_Display the user manual in web browser"))
-        category_vbox.pack_start(b, False)
         self.g_mainwin_user_resizeable = gu.nCheckButton('gui',
           'mainwin_user_resizeable', _("_Resizeable main window"))
         category_vbox.pack_start(self.g_mainwin_user_resizeable, False)
@@ -316,19 +301,27 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             lang = winlang.win32_get_langenviron()
             if lang in languages.languages:
                 idx = languages.languages.index(lang)
+            elif lang == 'C':
+                idx = languages.C_locale_idx
             else:
                 idx = 0
         else:
-            if cfg.get_string('app/lc_messages') in languages.languages:
-                idx = languages.languages.index(cfg.get_string('app/lc_messages'))
+            lang = cfg.get_string('app/lc_messages')
+            if lang in languages.languages:
+                idx = languages.languages.index(lang)
+            elif lang == 'C':
+                idx = languages.C_locale_idx
             else:
                 idx = 0
         self.g_language.set_active(idx)
         def f(combobox):
-            cfg.set_string('app/lc_messages', languages.languages[combobox.get_active()])
+            if combobox.get_active() == languages.C_locale_idx:
+                lang = "C"
+            else:
+                lang = languages.languages[combobox.get_active()]
+            cfg.set_string('app/lc_messages', lang)
             if sys.platform == 'win32':
                 if combobox.get_active():
-                    lang = languages.languages[combobox.get_active()]
                     winlang.win32_put_langenviron(lang)
                 else:
                     winlang.win32_put_langenviron(None)
